****************************
The sherpa.plot.utils module
****************************

.. currentmodule:: sherpa.plot.utils

.. automodule:: sherpa.plot.utils

   .. rubric:: Functions

   .. autosummary::
      :toctree: api

      histogram_line
